sql_results = """
SELECT 
  date_pst,
  ghost_user_id,
  session_id,
  page_session_id,
  section,
  section_pos,
  item_pos,
  item_id,
  page_type,
  os_type,

  item_type,
  item_type_augmented,
  is_promoted,

  num_snaps_available, 
  total_media_duration_secs AS media_duration_secs,

  num_impression, 
  num_long_impression, 
  
  story_view_time,
  num_snap_views,
  num_story_views,

  num_tap_story_view,
  num_auto_advance_story_view,
  num_swipe_story_view

FROM `sc-analytics.report_discover_feed.result_level_interaction_{{table_date}}`
WHERE MOD(ABS(FARM_FINGERPRINT(ghost_user_id)), {sample_rate}) = 0
"""

sql_page_session = """
  SELECT 
    date_pst,
    ghost_user_id,
    page_session_id,
    num_page_scroll,
    num_page_scroll_friends,
    num_page_scroll_subscriptions,
    num_page_refresh,
    num_page_open,
    num_page_view,
    is_abandoned,
    is_abandoned_no_scroll,
    has_any_story_view,
    has_story_view,
    has_following_story_view,
    has_public_user_following_story_view,
    has_publisher_story_view,
    has_publisher_following_story_view,
    has_happy_view,
    page_view_time,
    num_impressions,
    long_session_with_no_imp,
    
    IF(max_initial_num_unread_items_df_friends > max_num_items_available_df_friends,
      max_initial_num_unread_items_df_friends, max_num_items_available_df_friends) AS num_df_friend_stories_available,
    IF(max_initial_num_unread_items_df_friends > 0 AND min_final_num_unread_items_df_friends = 0, 
      1, 0) AS is_df_friend_story_cleared
  FROM `sc-analytics.report_discover_feed.page_session_level_metrics_{{table_date}}`
  WHERE MOD(ABS(FARM_FINGERPRINT(ghost_user_id)), {sample_rate}) = 0
"""

sql_user_cohorts = """
SELECT 
  * except(
      os_type, 
      user_id, 
      inferred_age_bucket,
      gender
    )
FROM `sc-analytics.report_search.user_cohorts_{{table_date}}` 
"""

sql_master = """
SELECT
  A.* except (date_pst, ghost_user_id, page_session_id),
  B.*,
  C.* except (date_pst, ghost_user_id)
FROM (
  -- Results-level Data
  {sql_results}
  ) A
LEFT OUTER JOIN (
  -- Page Session Data
  {sql_page_session}
) B
USING (date_pst, ghost_user_id, page_session_id)
LEFT OUTER JOIN (
  -- User Cohorts Data
  {sql_user_cohorts}
) C
USING (date_pst, ghost_user_id)
"""

sql_user_level = """
SELECT
    A.event_date,
    A.country,
    A.top_device AS os_type,
    A.age,
    A.gender,
    1 AS app_uu,
    B.*
FROM
    `sc-analytics.report_app.dau_user_country_{{table_date}}` A
LEFT JOIN (
    SELECT 
        date_pst,
        ghost_user_id,
        country_bucket,
        bidirectional_friend_status,
        df_non_friend_story_engagement_status,
        app_engagement_status,

        avg(num_tap_story_view)         avg_num_tap_story_view,
        avg(pct_tap_story_view)         pct_tap_story_view,

        count(1)   df_session,
        IF(count(1)>0, 1, 0) df_uu,
        SUM(if(num_page_view>0, 1, 0))   df_page_view_session,
        SUM(if(num_page_open>0, 1, 0))   df_page_open_session,
        SUM(if(num_page_scroll>0, 1, 0))   df_scroll_session,
        IF(SUM(if(num_page_scroll>0, 1, 0))>0, 1, 0) df_scroll_uu,
        SUM(if(num_impression>0, 1, 0))   df_imp_session,
        IF(SUM(if(num_impression>0, 1, 0))>0, 1, 0) df_imp_uu,
        SUM(if(num_story_view>0, 1, 0))   df_story_view_session,
        IF(SUM(if(num_story_view>0, 1, 0))>0, 1, 0) df_story_view_uu,
        SUM(if(num_friend_story_view>0, 1, 0))   df_friend_story_view_session,
        IF(SUM(if(num_friend_story_view>0, 1, 0))>0, 1, 0) df_friend_story_view_uu,
        SUM(if(num_non_friend_story_view>0, 1, 0))   df_non_friend_story_view_session,
        IF(SUM(if(num_non_friend_story_view>0, 1, 0))>0, 1, 0) df_non_friend_story_view_uu
    FROM (
        -- User / Page session aggregation
        SELECT
            date_pst,
            ghost_user_id,    
            page_session_id,

            country_bucket,
            bidirectional_friend_status,
            df_non_friend_story_engagement_status,
            app_engagement_status,

            SUM(num_page_open) num_page_open,
            SUM(num_page_view) num_page_view,
            SUM(num_story_views) num_story_view,
            SUM(num_tap_story_view) num_tap_story_view,
            SUM(IF(item_type in ('FRIEND'), num_story_views, 0)) num_friend_story_view,
            SUM(IF(item_type not in ('FRIEND'), num_story_views, 0)) num_non_friend_story_view,
            SUM(num_tap_story_view) / SUM(num_story_views) pct_tap_story_view,
            SUM(num_impression) num_impression,
            SUM(num_page_scroll) num_page_scroll,
            SUM(num_long_impression) num_long_impression
        FROM 
            `search-analytics-156901.dev_test.{}{{table_date}}`
        WHERE page_type = 'DISCOVER_FEED'
        GROUP BY 1,2,3,4,5,6,7
    )
    GROUP BY 1,2,3,4,5,6
) B
USING (ghost_user_id) 
WHERE
    A.app_application_open_count > 0
    AND A.app_version >= '10.23'
    AND MOD(ABS(FARM_FINGERPRINT(ghost_user_id)), {}) = 0
"""
